@@ -745,6 +745,14 @@ def scheduler_validator(param_key, param_value, pcluster_config):
     if pcluster_config.get_section("cluster").get_param_value("base_os") not in supported_os:
         errors.append("'{0}' scheduler supports the following Operating Systems: {1}".format(param_value, supported_os))
 
+    will_be_deprecated = ["sge", "torque"]
+    wiki_url = "https://github.com/aws/aws-parallelcluster/wiki/Deprecation-of-SGE-and-Torque-in-ParallelCluster"
+    if param_value in will_be_deprecated:
+        warnings.append(
+            "The job scheduler you are using ({0}) is scheduled to be deprecated in future releases of "
+            "ParallelCluster. More information is available here: {1}".format(param_value, wiki_url)
+        )
+
     return errors, warnings
 
 
@@ -839,3 +847,16 @@ def intel_hpc_validator(param_key, param_value, pcluster_config):
         )
 
     return errors, warnings
+
+
+def base_os_validator(param_key, param_value, pcluster_config):
+    warnings = []
+
+    eol_2020 = ["centos6", "alinux"]
+    if param_value in eol_2020:
+        warnings.append(
+            "The operating system you are using ({0}) will reach end-of-life in late 2020. It will be deprecated in "
+            "future releases of ParallelCluster".format(param_value)
+        )
+
+    return [], warnings
